#ifndef	cmlmbounce_h
#define	cmlmbounce_h

/*
** Copyright 2000-2007 Double Precision, Inc.
** See COPYING for distribution information.
*/

static const char cmlmbounce_h_rcsid[]="$Id: cmlmbounce.h,v 1.3 2007/03/01 04:32:03 mrsam Exp $";

#include	"config.h"

#include	<string>

int dobounce(const char *);
int dobounce1(const char *);
int dobounce2(const char *);
int bouncewarning(std::string, std::string, std::string);

#endif
